==> icecat-3.5.tar.bz2: icecat-3.5/content/xslt/src/xslt/txBufferingHandler.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is TransforMiiX XSLT processor code.
 *
 * The Initial Developer of the Original Code is
 * Jonas Sicking.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jonas Sicking <jonas@sicking.cc>
 *   Peter Van der Beken <peterv@propagandism.org>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef txBufferingHandler_h__
#define txBufferingHandler_h__

#include "txXMLEventHandler.h"
#include "nsString.h"
#include "nsVoidArray.h"
#include "nsAutoPtr.h"

class txOutputTransaction;
class txCharacterTransaction;

class txResultBuffer
{
public:
    ~txResultBuffer();

    nsresult addTransaction(txOutputTransaction* aTransaction);

    /**
     * Flush the transactions to aHandler. Some handlers create a new handler
     * and replace themselves with the new handler. The pointer that aHandler
     * points to should be updated in that case.
     */
    nsresult flushToHandler(txAXMLEventHandler** aHandler);

    txOutputTransaction* getLastTransaction();

    nsString mStringValue;

private:
    nsVoidArray mTransactions;
};

class txBufferingHandler : public txAXMLEventHandler
{
public:
    txBufferingHandler();

    TX_DECL_TXAXMLEVENTHANDLER

protected:
    nsAutoPtr<txResultBuffer> mBuffer;
    PRPackedBool mCanAddAttribute;
};

#endif /* txBufferingHandler_h__ */

==> icecat-6.0.1-2.tar.bz2: icecat-6.0.1-2/content/xslt/src/xslt/txBufferingHandler.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is TransforMiiX XSLT processor code.
 *
 * The Initial Developer of the Original Code is
 * Jonas Sicking.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jonas Sicking <jonas@sicking.cc>
 *   Peter Van der Beken <peterv@propagandism.org>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef txBufferingHandler_h__
#define txBufferingHandler_h__

#include "txXMLEventHandler.h"
#include "nsString.h"
#include "nsTArray.h"
#include "nsAutoPtr.h"

class txOutputTransaction;
class txCharacterTransaction;

class txResultBuffer
{
public:
    txResultBuffer();
    ~txResultBuffer();

    nsresult addTransaction(txOutputTransaction* aTransaction);

    nsresult flushToHandler(txAXMLEventHandler* aHandler);

    txOutputTransaction* getLastTransaction();

    nsString mStringValue;

private:
    nsTArray<txOutputTransaction*> mTransactions;
};

class txBufferingHandler : public txAXMLEventHandler
{
public:
    txBufferingHandler();
    virtual ~txBufferingHandler();

    TX_DECL_TXAXMLEVENTHANDLER

protected:
    nsAutoPtr<txResultBuffer> mBuffer;
    PRPackedBool mCanAddAttribute;
};

#endif /* txBufferingHandler_h__ */
